From 9782713e94126bc59a951f34b6eaeea24eb556cb Mon Sep 17 00:00:00 2001
From: James Moger <james.moger@gitblit.com>
Date: Tue, 21 May 2013 17:37:35 -0400
Subject: [PATCH] Documentation
---
src/main/java/com/gitblit/GitBlit.java | 72 ++++++++++++++++++++++++++++-------
1 files changed, 57 insertions(+), 15 deletions(-)
diff --git a/src/main/java/com/gitblit/GitBlit.java b/src/main/java/com/gitblit/GitBlit.java
index 01ebe08..081b74a 100644
--- a/src/main/java/com/gitblit/GitBlit.java
+++ b/src/main/java/com/gitblit/GitBlit.java
@@ -18,6 +18,7 @@
import java.io.BufferedReader;
import java.io.File;
import java.io.FileFilter;
+import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
@@ -127,7 +128,6 @@
import com.gitblit.wicket.GitBlitWebSession;
import com.gitblit.wicket.WicketUtils;
import com.google.gson.Gson;
-import com.google.gson.GsonBuilder;
import com.google.gson.JsonIOException;
import com.google.gson.JsonSyntaxException;
import com.google.gson.reflect.TypeToken;
@@ -159,8 +159,7 @@
private final List<FederationModel> federationRegistrations = Collections
.synchronizedList(new ArrayList<FederationModel>());
- private final List<GitClientApplication> clientApplications = Collections
- .synchronizedList(new ArrayList<GitClientApplication>());
+ private final ObjectCache<Collection<GitClientApplication>> clientApplications = new ObjectCache<Collection<GitClientApplication>>();
private final Map<String, FederationModel> federationPullResults = new ConcurrentHashMap<String, FederationModel>();
@@ -568,23 +567,46 @@
* Returns the list of custom client applications to be used for the
* repository url panel;
*
* @return a list of client applications
*/
- public List<GitClientApplication> getClientApplications() {
- if (clientApplications.isEmpty()) {
+ public Collection<GitClientApplication> getClientApplications() {
+ // prefer user definitions, if they exist
+ File userDefs = new File(baseFolder, "clientapps.json");
+ if (userDefs.exists()) {
+ Date lastModified = new Date(userDefs.lastModified());
+ if (clientApplications.hasCurrent("user", lastModified)) {
+ return clientApplications.getObject("user");
+ } else {
+ // (re)load user definitions
+ try {
+ InputStream is = new FileInputStream(userDefs);
+ Collection<GitClientApplication> clients = readClientApplications(is);
+ is.close();
+ if (clients != null) {
+ clientApplications.updateObject("user", lastModified, clients);
+ return clients;
+ }
+ } catch (IOException e) {
+ logger.error("Failed to deserialize " + userDefs.getAbsolutePath(), e);
+ }
+ }
+ }
+
+ // no user definitions, use system definitions
+ if (!clientApplications.hasCurrent("system", new Date(0))) {
try {
InputStream is = getClass().getResourceAsStream("/clientapps.json");
Collection<GitClientApplication> clients = readClientApplications(is);
is.close();
if (clients != null) {
- clientApplications.clear();
- clientApplications.addAll(clients);
+ clientApplications.updateObject("system", new Date(0), clients);
}
} catch (IOException e) {
logger.error("Failed to deserialize clientapps.json resource!", e);
}
}
- return clientApplications;
+
+ return clientApplications.getObject("system");
}
private Collection<GitClientApplication> readClientApplications(InputStream is) {
@@ -592,7 +614,7 @@
Type type = new TypeToken<Collection<GitClientApplication>>() {
}.getType();
InputStreamReader reader = new InputStreamReader(is);
- Gson gson = new GsonBuilder().create();
+ Gson gson = JsonUtils.gson();
Collection<GitClientApplication> links = gson.fromJson(reader, type);
return links;
} catch (JsonIOException e) {
@@ -1342,11 +1364,12 @@
// optionally (re)calculate repository sizes
if (getBoolean(Keys.web.showRepositorySizes, true)) {
+ ByteFormat byteFormat = new ByteFormat();
msg = "{0} repositories identified with calculated folder sizes in {1} msecs";
for (String repository : repositories) {
RepositoryModel model = getRepositoryModel(repository);
if (!model.skipSizeCalculation) {
- calculateSize(model);
+ model.size = byteFormat.format(calculateSize(model));
}
}
} else {
@@ -1537,6 +1560,10 @@
}
model.lastChange = JGitUtils.getLastChange(r);
+ if (!model.skipSizeCalculation) {
+ ByteFormat byteFormat = new ByteFormat();
+ model.size = byteFormat.format(calculateSize(model));
+ }
}
r.close();
@@ -3486,6 +3513,8 @@
// extract the resource to the directory if it does not exist
File f = new File(toDir, resource.substring(path.length()));
if (!f.exists()) {
+ InputStream is = null;
+ OutputStream os = null;
try {
if (resource.charAt(resource.length() - 1) == '/') {
// directory
@@ -3494,20 +3523,33 @@
} else {
// file
f.getParentFile().mkdirs();
- InputStream is = context.getResourceAsStream(resource);
- OutputStream os = new FileOutputStream(f);
+ is = context.getResourceAsStream(resource);
+ os = new FileOutputStream(f);
byte [] buffer = new byte[4096];
int len = 0;
while ((len = is.read(buffer)) > -1) {
os.write(buffer, 0, len);
}
- is.close();
- os.close();
}
} catch (FileNotFoundException e) {
logger.error("Failed to find resource \"" + resource + "\"", e);
} catch (IOException e) {
logger.error("Failed to copy resource \"" + resource + "\" to " + f, e);
+ } finally {
+ if (is != null) {
+ try {
+ is.close();
+ } catch (IOException e) {
+ // ignore
+ }
+ }
+ if (os != null) {
+ try {
+ os.close();
+ } catch (IOException e) {
+ // ignore
+ }
+ }
}
}
}
@@ -568,23 +567,46 @@
* repository url panel;
*
- * @return a list of client applications
+ * @return a collection of client applications
*/
--
Gitblit v1.9.1